Clazz.declarePackage("JSV.common");
Clazz.declareInterface(JSV.common, "XYScaleConverter");
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
